summaryrefslogtreecommitdiffstats
path: root/src/clickablelabel.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/clickablelabel.h')
-rw-r--r--src/clickablelabel.h13
1 files changed, 7 insertions, 6 deletions
diff --git a/src/clickablelabel.h b/src/clickablelabel.h
index 0198974..c65c001 100644
--- a/src/clickablelabel.h
+++ b/src/clickablelabel.h
@@ -21,23 +21,24 @@
#ifndef CLICKABLELABEL_H
#define CLICKABLELABEL_H
#include <qlabel.h>
/** This class is a QLabel that can emit a clicked() signal when clicked !
* @author S�astien Laot
*/
-class ClickableLabel : public QLabel
+class ClickableLabel : public TQLabel
{
Q_OBJECT
+ TQ_OBJECT
public:
/** Construtor, initializer and destructor */
- ClickableLabel(QWidget *parent = 0, const char *name = 0)
- : QLabel(parent, name) {}
+ ClickableLabel(TQWidget *tqparent = 0, const char *name = 0)
+ : TQLabel(tqparent, name) {}
~ClickableLabel() {}
signals:
void clicked();
protected:
- virtual void mousePressEvent(QMouseEvent *event);
+ virtual void mousePressEvent(TQMouseEvent *event);
};
#endif // CLICKABLELABEL_H
@@ -21,23 +21,24 @@
#ifndef CLICKABLELABEL_H
#define CLICKABLELABEL_H
-#include <qlabel.h>
+#include <tqlabel.h>
-/** This class is a QLabel that can emit a clicked() signal when clicked !
+/** This class is a TQLabel that can emit a clicked() signal when clicked !
* @author S�astien Laot
*/